import basket
from import_export.admin import ExportActionMixin, ImportMixin
from import_export.formats.base_formats import CSV
from import_export.forms import export_action_form_factory


class CSV_quoting(CSV):
    def export_data(self, dataset, **kwargs):
        kwargs['delimiter'] = ';'
        kwargs['quoting'] = 1
        return super().export_data(dataset, **kwargs)

    def create_dataset(self, in_stream, **kwargs):
        kwargs['delimiter'] = ';'
        kwargs['quoting'] = 1
        # remove insane utf-8 BOM set by excel
        if in_stream.startswith('\ufeff'):
            in_stream = in_stream[1:]
        return super().create_dataset(in_stream, **kwargs)


class ResetFormMixin:
    """
    remove empty choice for export format
    """

    def __init__(self, *args, **kwargs):
        """
        Adds a custom action form initialized with the available export
        formats.
        """
        choices = []
        formats = self.get_export_formats()
        if formats:
            # choices.append(('', '---'))
            for i, f in enumerate(formats):
                choices.append((str(i), f().get_title()))

        self.action_form = export_action_form_factory(choices)
        super().__init__(*args, **kwargs)


class BasketBigFilterImportExportMixin(
    ImportMixin,
    ExportActionMixin,
    ResetFormMixin,
    basket.MixinBigFilter,
    basket.MixinBasketAdmin,
):
    """
    Merge of import_export.Import import_export.ExportAction + basket (template)
    + minor customization
    """

    # class Media:
    #     js = [
    #         # FIXME: valider le bon chargement de la lib
    #         'import_export/action_formats.js',
    #     ]
    change_list_template = "admin/import_export_basket/change_list_import.html"
    formats = [CSV_quoting]


class BasketImportExportMixin(
    ImportMixin, ExportActionMixin, ResetFormMixin, basket.MixinBasketAdmin
):
    """
    Merge of import_export.Import import_export.ExportAction + basket (template)
    + minor customization
    """

    # class Media:
    #     js = [
    #         # FIXME: valider le bon chargement de la lib
    #         'import_export/action_formats.js',
    #     ]
    change_list_template = "admin/import_export_basket/change_list_import.html"
    formats = [CSV_quoting]


class ImportExportMixin(ImportMixin, ExportActionMixin, ResetFormMixin):
    """
    Merge of import_export.Import import_export.ExportAction
    + minor customization
    """

    formats = [CSV_quoting]
