# -*- coding: utf-8 -*-
import logging

from django.core.management.base import BaseCommand

import gaby.contacts.models as cm
from gaby.siret import CheckSiret
from gaby.utils import Cpt

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "check database integrity: see --list for detail"

    def add_arguments(self, parser):
        parser.add_argument(
            '--no-dry-run',
            '-n',
            dest='dry_run',
            action='store_false',
            default=True,
            help='actually make change (default is dryrun)',
        )
        parser.add_argument(
            '--list',
            '-l',
            dest='list',
            action='store_true',
            default=False,
            help='list of available check/correct',
        )

    def handle(self, *args, **options):
        self.args = args
        self.options = options
        if self.options['list']:
            print(
                "assolement: check/recalculate assolement total in DonneesBio\n"
                "siret: check siret number is valide"
            )
        else:
            logger.warning("Launch fsck")
            self.check_assolement()
            self.check_siret()

    def check_assolement(self):
        print("## Check assolement total in donnee bio:")
        qs_elm = cm.DonneesBio.objects.all()
        cpt = Cpt("DonneesBio", len(qs_elm))
        nerr = 0
        for elm in qs_elm:
            change, sau_total, sau_total_bio = elm.update_assolement(
                commit=not self.options['dry_run']
            )
            if change:
                nerr += 1
                logger.warning("Assolement #{0} is wrong".format(elm.id))
            cpt()
        print(
            "Error {}: {}".format(
                'detected' if self.options['dry_run'] else 'corrected', nerr
            )
        )

    def check_siret(self):
        """
        check siret compliance and siret uniqness
        """
        print("## Check siret compliance in structure:")
        qs_elm = cm.Structure.objects.exclude(siret='').order_by('siret')
        cpt = Cpt("Structure", len(qs_elm))
        nerr = 0
        previous_siret, previous_elm = None, None
        for elm in qs_elm:
            status_siret = CheckSiret(elm.siret)
            if not status_siret.is_siret:
                nerr += 1
                logger.warning(
                    "Structure #{0.id} got a wrong siret: '{1}'".format(
                        elm, status_siret.siret
                    )
                )
            if previous_siret == status_siret.siret:
                nerr += 1
                logger.warning(
                    "Structure #{0.id} and #{1.id}: same siret: '{2}'".format(
                        previous_elm, elm, status_siret.siret
                    )
                )
            previous_siret, previous_elm = status_siret.siret, elm
            cpt()
        print(
            "Error {}: {}".format(
                'detected' if self.options['dry_run'] else 'corrected', nerr
            )
        )
