# -*- coding: utf-8 -*-
from django.contrib.auth import models as am
from django.test import TestCase
from django.urls import reverse

from gaby.contacts import models as cm
from gaby.contacts.settings_messages import AVERTISSEMENT_MESSAGE as w_msg
from gaby.contacts.tests.utils import cfty
from gaby.references import models as rm


class ValPersonne(TestCase):
    def setUp(self):
        self.usr = am.User.objects.create_superuser('usr', '', 'mdp')
        self.client.login(username=self.usr.username, password='mdp')
        self.usr1 = am.User.objects.create_user('usr1')
        self.fjur = rm.FormeJuridique()
        self.fjur.save()
        self.i_pm = {
            'date_creation': '2014-10-01',
            'date_derniere_modification': '2014-10-02',
            'utilisateur_derniere_modification': self.usr1,
            'f_juridique': self.fjur,
            'designation': "test",
        }
        self.i_p = {'nom': 'testnom', 'prenom': 'testprenom'}

    def test_personne_dateNaiss_struct(self):
        """Si une personne est rattachee a un agriculteur ou un agriculteur bio il
        doit - avoir une date de naissance
        """
        # Une personne rattachee a une structure sans date de naissance
        # sans erreur
        struc = cfty(cm.Structure, self.i_pm, statutbio=0)
        data = self.i_p.copy()
        data.update(
            {
                'structure': str(struc.id),
                'rdvpersonne_set-TOTAL_FORMS': '0',
                'rdvpersonne_set-INITIAL_FORMS': '0',
                'rdvpersonne_set-MAX_NUM_FORMS': '',
            }
        )
        path = reverse('admin:contacts_personne_add')
        response = self.client.post(path, data, follow=True)
        msg = [elm.message for elm in response.context['messages']]
        self.assertNotIn(w_msg["pers_af_agri_sans_date_naiss"], msg)

    def test_personne_dateNaiss_agri(self):
        "Si une personne est rattachee a une structure, on ne verifie pas"
        # Une personne rattachee a une structure sans date de naissance
        # sans erreur
        struc = cfty(cm.Structure, self.i_pm, statutbio=1)
        data = self.i_p.copy()
        data.update(
            {
                'structure': str(struc.id),
                'rdvpersonne_set-TOTAL_FORMS': '0',
                'rdvpersonne_set-INITIAL_FORMS': '0',
                'rdvpersonne_set-MAX_NUM_FORMS': '',
            }
        )
        path = reverse('admin:contacts_personne_add')
        response = self.client.post(path, data, follow=True)
        msg = [elm.message for elm in response.context['messages']]
        self.assertIn(w_msg["pers_af_agri_sans_date_naiss"], msg)
