# -*- coding: utf-8 -*-
from django.contrib.auth import models as am
from django.test import TestCase
from django.urls import reverse

from gaby.contacts import models as cm
from gaby.contacts import settings_messages as MSG
from gaby.contacts.tests.utils import cfty
from gaby.references import models as rm


class ValRdvMessage(TestCase):
    def setUp(self):
        self.messagePersonne = MSG.AVERTISSEMENT_MESSAGE[
            "rdv_collec_sans_part"
        ]
        self.titre = rm.Formation.objects.create(designation="test")
        self.usr1 = am.User.objects.create_superuser('usr1', '', 'mdp')
        self.fjur = rm.FormeJuridique.objects.create()
        self.i_pm = {
            'date_creation': '2014-10-01',
            'date_derniere_modification': '2014-10-02',
            'utilisateur_derniere_modification': self.usr1,
            'f_juridique': self.fjur,
        }
        self.pm = cfty(cm.Structure, self.i_pm)
        self.i_p = {
            'nom': 'testnom',
            'prenom': 'testprenom',
            'date_naissance': '2000-01-01',
            'utilisateur_derniere_modification': self.usr1,
            'structure': self.pm,
        }
        self.p = cfty(cm.Personne, self.i_p)
        self.data_rdv = {
            'technicien': str(self.usr1.id),
            'date': '2014-10-14',
            'rdvpersonne_set-TOTAL_FORMS': '0',
            'rdvpersonne_set-INITIAL_FORMS': '0',
            'rdvpersonne_set-MAX_NUM_FORMS': '',
            'rdvpersonnemorale_set-TOTAL_FORMS': '0',
            'rdvpersonnemorale_set-INITIAL_FORMS': '0',
            'rdvpersonnemorale_set-MAX_NUM_FORMS': '',
            'documentjoint_set-TOTAL_FORMS': '0',
            'documentjoint_set-INITIAL_FORMS': '0',
            'documentjoint_set-MAX_NUM_FORMS': '',
        }

    def test_rdv_collectif_sans_participant(self):
        """ Un Rdv coll. doit avoir au moins 1 participant """
        # Rdv coll. sans participant avec message d'avertissement
        self.client.login(username=self.usr1.username, password='mdp')
        data_rdv = self.data_rdv.copy()
        data_rdv['est_confirme'] = True
        data_rdv['type_rdv'] = 'evt'
        data_rdv['titre_evt'] = str(self.titre.id)
        path = reverse('admin:contacts_rdv_add')
        response = self.client.post(path, data_rdv, follow=True)
        msg = []
        for message in list(response.context['messages']):
            msg.append(message.message)
        self.assertIn(self.messagePersonne, msg)

    def test_rdv_collectif_avec_participant(self):
        # Rdv indiv avec participant sans message d'avertissement
        self.client.login(username=self.usr1.username, password='mdp')
        data_rdv = self.data_rdv.copy()
        data_rdv['est_confirme'] = True
        data_rdv['type_rdv'] = 'evt'
        data_rdv['titre_evt'] = '1'
        data_rdv['rdvpersonne_set-TOTAL_FORMS'] = '1'
        data_rdv['rdvpersonne_set-0-personne'] = '1'
        path = reverse('admin:contacts_rdv_add')
        response = self.client.post(path, data_rdv, follow=True)
        msg = []
        for message in list(response.context['messages']):
            msg.append(message.message)
        self.assertNotIn(self.messagePersonne, msg)


# EOF
